@@ -20,6 +20,10 @@ public class C_Not extends C_Expression {
 	
 	public C_Not(C_Expression argument) {
 		this.argument = argument;
+		if (argument != null) {
+			this.readableExpression = "Not("
+					+ argument.getReadableExpression() + ")";
+		}
 	}
 
 	public C_OperatorType getOperator() {
@@ -45,7 +49,7 @@ public class C_Not extends C_Expression {
 
 	@Override
 	public String toString() {
-		return "C_Not [id=" + id + ", argument=" + argument + "]";
+		return "Not [id=" + id + ", argument=" + argument + "]";
 	}
 	
 	
